pub fn status() -> Option<RecordingStatus>Expand description
The current status: the live recording when one is active, otherwise the last finished
one; None when the process has never recorded.
pub fn status() -> Option<RecordingStatus>The current status: the live recording when one is active, otherwise the last finished
one; None when the process has never recorded.